summaryrefslogtreecommitdiff
path: root/avr/cli.c
diff options
context:
space:
mode:
Diffstat (limited to 'avr/cli.c')
-rw-r--r--avr/cli.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/avr/cli.c b/avr/cli.c
index 1a26206..77876af 100644
--- a/avr/cli.c
+++ b/avr/cli.c
@@ -177,7 +177,7 @@ char *process_macros(char *input, char *output)
if (c == '}') {
/* Terminate variable name */
*(inp-1) = '\0';
- const char *envval = getenv_char(varname);
+ const char *envval = getenv_str(varname);
*(inp-1) = '}';
/* Copy into the line if it exists */
if (envval != NULL)
@@ -210,7 +210,7 @@ char *process_macros(char *input, char *output)
* WARNING:
*
* We must create a temporary copy of the command since the command we get
* may be the result from getenv_char(), which returns a pointer directly to
* the environment data, which may change magicly when the command we run
* creates or modifies environment variables (like "bootp" does).
*
@@ -210,7 +210,7 @@ char *process_macros(char *input, char *output)
*
* We must create a temporary copy of the command since the command we get
- * may be the result from getenv_char(), which returns a pointer directly to
+ * may be the result from getenv_str(), which returns a pointer directly to
* the environment data, which may change magicly when the command we run
* creates or modifies environment variables (like "bootp" does).